@@ -14,7 +14,6 @@
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
-from nonebot_plugin_txt2img import Txt2Img
 from nonebot.matcher import Matcher
 from nonebot.typing import T_State
 from typing import Tuple
@@ -25,11 +24,10 @@ from .command import *
 from .l4d2_image.steam import url_to_byte
 from nonebot.plugin import PluginMetadata
 from .l4d2_data import sq_L4D2
-from .l4d2_anne.server import get_anne_ip
 from nonebot import get_driver
 from .l4d2_image.vtfs import img_to_vtf
 from .l4d2_queries.ohter import load_josn
-from .l4d2_queries.qqgroup import write_json
+from .l4d2_queries.qqgroup import write_json,ip_anne_list
 from .l4d2_file import updown_l4d2_vpk
 from .txt_to_img import mode_txt_to_img
 # from .l4d2_server import RCONClient
@@ -39,7 +37,7 @@ scheduler = require("nonebot_plugin_apscheduler").scheduler
 driver = get_driver()
 
 
-__version__ = "0.3.2"
+__version__ = "0.3.3"
 __plugin_meta__ = PluginMetadata(
     name="求生之路小助手",
     description='群内对有关求生之路的查询和操作',
@@ -91,7 +89,6 @@ async def _(matcher:Matcher,event: NoticeEvent):
 
 @up.got("is_sure",prompt="请选择上传位置（输入阿拉伯数字)")    
 async def _(matcher: Matcher):
-    logger.info(l4_file)
     args = matcher.get_arg('txt')
     map_path = Path(l4_file[CHECK_FILE],vpk_path)
     sleep(1)
@@ -350,28 +347,10 @@ async def _(args:Message = CommandArg()):
     else:
         message = await write_json(msg)
         await updata.finish(message)
-
-@get_anne.handle()
-async def _(args:Message = CommandArg()):
-    msg = args.extract_plain_text()
-    if msg.isdigit():
-        msg = '云' + msg
-        logger.info(msg)
-        ip = await get_anne_ip(msg)
-        if ip:
-            message = await get_anne_server_ip(ip)
-            await get_anne.finish(message)
-    
+  
 @read_ip.handle()
-async def _(event:GroupMessageEvent):
-    group = event.group_id
-    ip_list = []
-    keys = ANNE_IP.keys()
-    for key in keys:
-        ip = ANNE_IP[key]
-        host,port = split_maohao(ip)
-        ip_list.append((key,group,host,port))
-    img = await qq_ip_queries_pic(ip_list)
+async def _():
+    img = await qq_ip_queries_pic(ip_anne_list)
     await read_ip.finish(MessageSegment.image(img))
 
 @tan_jian.handle()
@@ -393,15 +372,27 @@ async def _(event:MessageEvent):
 async def _(command: str = RawCommand(),args:Message = CommandArg()):
     logger.info(command)
     msg:str = args.extract_plain_text()
-    logger.info(msg)
-    message = await json_server_to_tag_dict(command,msg)
-    if len(message) == 0:
-        # 关键词不匹配，忽略
-        return
-    ip = str(message['host']) + ':' + str(message['port'])
-    logger.info(ip)
-    msg= await get_anne_server_ip(ip)
-    await get_ip.finish(msg)
+    if not msg:
+        # 以图片输出全部当前
+        this_ips = ALL_HOST[command]
+        ip_list = []
+        for one_ip in this_ips:
+            host,port = split_maohao(one_ip['ip'])
+            ip_list.append((one_ip['id'],host,port))
+        img = await qq_ip_queries_pic(ip_list)
+        await read_ip.finish(MessageSegment.image(img))
+    else:
+        message = await json_server_to_tag_dict(command,msg)
+        if len(message) == 0:
+            # 关键词不匹配，忽略
+            return
+        ip = str(message['ip'])
+        logger.info(ip)
+        try:
+            msg= await get_anne_server_ip(ip)
+            await get_ip.finish(msg)
+        except OSError:
+            await get_ip.finish('服务器无响应')
 
             
 @vtf_make.handle()
