@@ -1,21 +1,21 @@
 from ..l4d2_data.serverip import L4D2Server
 from ..l4d2_image import server_ip_pic
-from . import queries,player_queries,queries_dict,player_queries_anne_dict
+from . import queries,player_queries,queries_dict,player_queries_anne_dict,msg_ip_to_list
 from nonebot.log import logger
 import random
 import asyncio
 import re
 from ..message import PRISON,QUEREN,KAILAO
-from .ohter import ANNE_HOST
+from .ohter import ALL_HOST
 from typing import List,Dict
-from pathlib import Path
 try:
     import ujson as json
 except:
     import json
 si = L4D2Server()
-errors = (TypeError,ValueError,ConnectionResetError,ConnectionRefusedError,asyncio.exceptions.TimeoutError)
+errors = (ConnectionRefusedError,ConnectionResetError,asyncio.exceptions.TimeoutError,OSError)
 # errors = (TypeError,KeyError,ValueError,ConnectionResetError,TimeoutError)
+
 async def get_qqgroup_ip_msg(qqgroup):
     """首先，获取qq群订阅数据，再依次queries返回ip原标"""
     ip_list = await si.query_server_ip(qqgroup)
@@ -51,22 +51,22 @@ async def qq_ip_queries(msg:List[tuple]):
         messsage += '序号、'+ str(number) + '\n' + msg1 + msg2 + '--------------------\n'
     return messsage
             
-async def qq_ip_queries_pic(msg:List[tuple]):
-    """输入一个ip的四元元组组成的列表，返回一个输出消息的图片"""
+async def qq_ip_queries_pic(msg:list):
+    """输入一个ip的三元元组组成的列表，返回一个输出消息的图片"""
     msg_list = []
-    print(msg)
-    for i in msg:
-        number,qqgroup,host,port = i
-        try:
-            msg2 = await player_queries_anne_dict(host,port)
-            msg1 = await queries_dict(host,port)
-            msg1.update(msg2)
-            msg1.update({'number':number})
-            # msg1是一行数据完整的字典
-            msg_list.append(msg1)
-        except (TypeError,ConnectionResetError):
-            pass
-    pic = await server_ip_pic(msg_list)
+    if msg != []:
+        for i in msg:
+            number,host,port = i
+            try:
+                msg2 = await player_queries_anne_dict(host,port)
+                msg1 = await queries_dict(host,port)
+                msg1.update({'Players':msg2})
+                msg1.update({'number':number})
+                # msg1是一行数据完整的字典
+                msg_list.append(msg1)
+            except errors:
+                pass
+        pic = await server_ip_pic(msg_list)
     return pic
     
 async def get_tan_jian(msg:List[tuple],mode:int):
@@ -74,31 +74,26 @@ async def get_tan_jian(msg:List[tuple],mode:int):
     msg_list = []
     rank = 0
     for i in msg:
-        number,qqgroup,host,port = i 
-        print(host)
-        print(port)
+        number,host,port = i 
         try:
             if mode == 1:
                 # 探监
                 msg2 = await player_queries_anne_dict(host,port)
                 point = 0
-                if 'Players' not in msg2:
-                    continue
-                for i in msg2['Players']:
+                for i in msg2:
                     point += int(i['Score'])
                 logger.info(point)
                 msg1 = await queries_dict(host,port)
-                print(msg1)
                 sp:str = msg1['name']
+                if '特' not in sp:
+                    continue
                 sp = int(sp.split('特')[0].split('[')[-1])
                 points = point/4
                 if points/sp <10:
-                    logger.info('不够牢')
                     continue
                 if 'HT' in msg1['name']:
-                    logger.info('HT训练忽略')
                     continue
-                msg1.update(msg2)
+                msg1.update({'Players':msg2})
                 msg1.update({'ranks':point})
                 ips = f'{host}:{str(port)}'
                 msg1.update({'ips':ips})
@@ -106,21 +101,26 @@ async def get_tan_jian(msg:List[tuple],mode:int):
                 msg_list.append(msg1)
             if mode == 2:
                 # 坐牢
+                # try:
                 msg1 = await queries_dict(host,port)
                 if '普通药役' in msg1['name']:
                     if '缺人' in msg1['name']:
                         msg2 = await player_queries_anne_dict(host,port)
-                        msg1.update(msg2)
+                        msg1.update({'Players':msg2})
                         ips = f'{host}:{str(port)}'
                         msg1.update({'ips':ips})
-                    # msg1是一行数据完整的字典
-
+                        # msg1是一行数据完整的字典
+                    else:
+                        continue
+                else:
+                    continue
+                msg_list.append(msg1)
             if mode == 3:
                 # 开牢
                 msg1 = await queries_dict(host,port)
                 if '[' not in msg1['name']:
                     msg2 = await player_queries_anne_dict(host,port)
-                    msg1.update(msg2)
+                    msg1.update({'Players':msg2})
                     ips = f'{host}:{str(port)}'
                     msg1.update({'ips':ips})
                     # msg1是一行数据完整的字典
@@ -156,23 +156,12 @@ async def get_tan_jian(msg:List[tuple],mode:int):
     message += '\n' + '名称：' + mse['name'] + '\n'
     message += '地图：' + mse['map_'] + '\n'
     message += f"玩家：{mse['players']} / {mse['max_players']}\n"
-    n = 0
+    print(mse['Players'])
     try:
-        max_duration_len = max([len(str(i['Duration'])) for i in mse['Players']])
-        max_score_len = max([len(str(i['Score'])) for i in mse['Players']])
-        for i in mse['Players']:
-            n += 1 
-            name = i['Name']
-            Score = i['Score']
-            Duration = i['Duration']
-            if Score in('0',0,None) :
-                Score = '摸'
-            soc = "[{:>{}}]".format(Score,max_score_len)
-            dur = "{:^{}}".format(Duration, max_duration_len)
-            message += f'{soc} | {dur} | {name} \n'
-    except KeyError:
+        message += await msg_ip_to_list(mse['Players'])
+    except (KeyError):
         message += '服务器里，是空空的呢\n'
-    message += 'connect ' + mse['ips']
+    message += 'connect ' + mse['ip']
     return message
 
 async def get_server_ip(number):
@@ -198,11 +187,11 @@ async def write_json(data_str:str):
     logger.info(data_list)
     if data_list[0]=="添加":
         add_server = {}
-        server_dict = ANNE_HOST.get(data_list[1], {})
+        server_dict = ALL_HOST.get(data_list[1], {})
         if not server_dict:
             logger.info('新建分支')
-            ANNE_HOST[data_list[1]] = []
-        for key,value in ANNE_HOST.items():
+            ALL_HOST[data_list[1]] = []
+        for key,value in ALL_HOST.items():
             if data_list[1] == key:
                 ids = []
                 # 序号
@@ -233,24 +222,31 @@ async def write_json(data_str:str):
                 except KeyError:
                     return 'ip格式不正确【114.11.4.514:9191】'
                 value.append(add_server)
-                ANNE_HOST.update({key:value})
+                ALL_HOST.update({key:value})
                 with open('data/L4D2/l4d2.json', "r", encoding="utf8") as f_new:
-                    json.dump(ANNE_HOST, f_new, ensure_ascii=False, indent=4)
+                    json.dump(ALL_HOST, f_new, ensure_ascii=False, indent=4)
                 return f'添加成功，指令为{key}{data_id}'
             
     elif data_list[0]=="删除":
-        for key,value in ANNE_HOST.items():
+        for key,value in ALL_HOST.items():
             value:List[dict]
             if data_list[1] == key:
                 for server in value:
                     if int(data_list[2]) == server['id']:
                         value.remove(server)
                         if not value:
-                            ANNE_HOST.pop(key)
+                            ALL_HOST.pop(key)
                         else:
-                            ANNE_HOST[key] = value
+                            ALL_HOST[key] = value
                         with open('data/L4D2/l4d2.json', "r", encoding="utf8") as f_new:
-                            json.dump(ANNE_HOST, f_new, ensure_ascii=False, indent=4)
+                            json.dump(ALL_HOST, f_new, ensure_ascii=False, indent=4)
                         return '删除成功喵'
                 return '序号不正确，请输入【求生更新 删除 腐竹 序号】'
-        return '腐竹名不存在，请输入【求生更新 删除 腐竹 序号】'    
\ No newline at end of file
+        return '腐竹名不存在，请输入【求生更新 删除 腐竹 序号】'    
+    
+
+ips = ALL_HOST['云']
+ip_anne_list = []
+for one_ip in ips:
+    host,port = split_maohao(one_ip['ip'])
+    ip_anne_list.append((one_ip['id'],host,port))
\ No newline at end of file
